#
# spec file for package qgit
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qgit
Version:        2.10
Release:        1.13
Summary:        Graphical Git Repository Viewer
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://github.com/tibirna/qgit
Source:         https://github.com/tibirna/qgit/archive/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8.11
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake(Qt5Core) >= 5.14.0
BuildRequires:  cmake(Qt5Widgets) >= 5.14.0
Requires:       git-core >= 1.5.5

%description
QGit is a git GUI viewer built on Qt/C++.

With qgit you will be able to browse revisions history, view patch
content and changed files, graphically following different development
branches.

Features

- View revisions, diffs, files history, files annotation, archive tree.

- Commit changes visually cherry picking modified files.

- Apply or format patch series from selected commits, drag and drop
commits between two instances of qgit.

- Associate commands sequences, scripts and anything else executable to
a custom action. Actions can be run from menu and corresponding output
is grabbed by a terminal window.

- qgit implements a GUI for the most common StGIT commands like push/pop
and apply/format patches. You can also create new patches or refresh
current top one using the same semantics of git commit,  i.e. cherry
picking single modified files.

%prep
%setup -q -n qgit-qgit-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license COPYING.rtf
%doc README.adoc
%{_bindir}/qgit
%{_datadir}/applications/qgit.desktop
%{_datadir}/icons/hicolor/scalable/apps/qgit.svg
%{_datadir}/icons/hicolor/48x48/apps/qgit.png
%{_datadir}/metainfo/qgit.appdata.xml

%changelog
* Fri Feb  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.10:
  * Upgrade icons (use SVG)
  * Add "Commit" column to history view to show the short commit hash.
  * build: sync qmake config to latest changes for cmake config
  * Bump minimum Qt version to 5.14
  * Support --help, --help-all and --version in command line
  * Fix build on MacOS
  * Add option to open external diff tool on double click
  * Add branch name to window title
  * Fix loading of invalid cache file
  * Settings: Option to display short hash instead of full length hash
  * Save and restore the list view column sizes
  * Make drag & drop functionality optional
  * Make Settings dialog accessible on macOS
  * Improve logic to detect failed external commands under Unix-like OSes
  * Don't rely on STDERR for determining whether command failed
  * Compilation cleanup
  * Support for fractional device pixel ratio
  * Update project URLs to GitHub repo
* Mon May 10 2021 Dirk Müller <dmueller@suse.com>
- stop owning directories provided by filesystem (bsc#1184786)
* Thu Feb  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.9 (boo#1162940):
  * Improved branch display in context menus
  * Improved general display
  * Improved navigation
* Fri Jul 13 2018 antoine.belvire@opensuse.org
- Update to 2.8:
  * Fix file browsing.
  * Fix compilation issues on Windows.
  * Fix breakage of keybindings and menu item accelerators.
- Update to 2.7:
  * No changelog provided.
- Use cmake for build.
- Remove qgit4.desktop from rpm sources (now present in upstream
  sources).
* Mon Jan  2 2017 dmueller@suse.com
- update to 2.6:
  * switch to Qt5 (bsc#988809)
- spec-cleaner run
* Tue Jun  4 2013 dmueller@suse.com
- update to 2.5:
  * fixed sorting of tree-view
  * better support for dark GUI color schemes
  * fixed off-sync line numbers in the annotation file view
* Sun Sep 16 2012 schwab@linux-m68k.org
- Don't strip binaries
* Thu Dec  1 2011 dmueller@suse.de
- update to 2.4 (bnc#734180):
  * fix functionality losses with newer git releases
  * shortlog parsing fixes
  * display cleanups
* Wed Sep  9 2009 dmueller@suse.de
- update to 2.3:
  * mainly a manteinance release with added a new and
  better graph look
* Sat Apr  4 2009 dmueller@suse.de
- rediff patches
* Thu Jul 17 2008 dmueller@suse.de
- update to 2.2:
  * no changelog available
* Sat May 17 2008 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
* Mon Mar 10 2008 dmueller@suse.de
- udpate to 2.1:
  * Lots of fixes from 2.0, see detailed change log at
    http://git.kernel.org/?p=qgit/qgit4.git;a=shortlog
  * Speed improvements
* Mon Oct  8 2007 dmueller@suse.de
- update to 2.0:
  * Qt4 port, less security vulnerabilities
* Mon Oct  8 2007 dmueller@suse.de
- update to 1.5.7
* Sun Aug 12 2007 dmueller@suse.de
- update to 1.5.6
* Thu May 17 2007 dmueller@suse.de
- Update to 1.5.5
* Thu Jan 18 2007 bwalle@suse.de
- Update to 1.5.4
* Mon Nov 13 2006 mhopf@suse.de
- Update to 1.5.3
* Thu Jul 20 2006 mhopf@suse.de
- Initial commit (version 1.4)
